﻿using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;
using WardGroup.Components;
using WardGroup.BusinessObjects;
using WardGroup.Services;
using Infragistics.WebUI.UltraWebGrid;
using Infragistics.Web.UI.GridControls;
using Infragistics.Web.UI.ListControls;

namespace WardGroup
{

    /// <summary>
    /// 
    /// </summary>
    [GrantAccess("SystemAdmin")]
    [GrantAccess("Consultant")]
    public partial class Allocations12 : BasePage
    {
        private bool isNumberOfYearchanged = false;

        #region "Events"

        protected void Page_Load(object sender, EventArgs e)
        {
            if (currentMI.modelInstanceID == Guid.Empty || currentMM.MM_P_OR_F_OR_T != "T")
            {
                Response.Redirect("Default.aspx");
                return;
            }

            currentPage = "Allocations";
            baseLineYear.Text = this.currentMI.modelInstanceYear.ToString();
            if (!IsPostBack)
            {
                int i = 1;
                foreach (ModelInstance mi in currentMM.ModelInstances)
                {
                    if (currentMI.modelInstanceYear - mi.modelInstanceYear < 5 && currentMI.modelInstanceYear - mi.modelInstanceYear >= 0)
                    {
                        numberOfYears.Items.Add(i.ToString());
                        i++;
                    }
                }
                numberOfYears.DataBind();
                bindAllocationData();
            }

            //Page needs to be read only
            if (currentMM.readOnlyClient)
            {
                btnNewRow.Disabled = true;
                btnDeleteRow.Disabled = true;

            }

            //Assigning BaseLine Year
        }

        protected void numberOfYears_SelectedIndexChanged(object sender, EventArgs e)
        {
            isNumberOfYearchanged = true;
            bindAllocationData();
        }


        protected void Post1_Click1(object sender, EventArgs e)
        {
            //just needs to post back so updateRowBatch will fire.
            isNumberOfYearchanged = false;
        }



        #endregion

        #region "Private functions"

        /// <summary>
        /// This method "bindAllocationData" is used to fetch data from database for Allocations and bind it to Infragistics UltrWebGrid
        /// </summary>
        private void bindAllocationData()
        {
            //Number of Years to Show
            int year = System.Convert.ToInt32(numberOfYears.SelectedValue);
            //Current year
            int currentYear = this.currentMI.modelInstanceYear;
            //For testing
            //int currentYear = 2006;

            Int32 index;
            List<string> msgs = new List<string>();

            //Create an instance of AllocationsService
            AllocationsService svc = null;
            DataSet allocations;

            //try
            //  {
            svc = new AllocationsService();

            //Assigning current logged in user id to authenticationInfo
            svc.authenticationInfo.userId = base.loggedInUserID;

            //Calling getAllocations to retrive all Allocations for given Model Instance ID in ALLOCATIONS table
            allocations = svc.getAllocations(this.currentMI.modelInstanceID, year);
            //for testing
            //allocations = svc.getAllocations(new Guid("4392F50B-1DEA-434C-BB95-338780148C73"));

            if (allocations.Tables.Count > 0)
            {
                allocations.Tables[0].TableName = "Allocations";
            }

            //Filter for number of years depends on selection
            string condition = "MI_Year in(" + currentYear + ",";

            if (year > 1)
            {


                for (index = 1; index <= year - 1; index++)
                {
                    condition = condition + (currentYear - index) + ",";
                }
            }

            condition = condition.Substring(0, condition.Length - 1) + ")";


            DataView allocationsYears = allocations.Tables["Allocations"].DefaultView;
            allocationsYears.RowFilter = condition;
            dgAllocation.DataSource = allocations.Tables["Allocations"];
            dgAllocation.DataBind();


            DropDownProvider ddp_AllocationType = new DropDownProvider();
            ddp_AllocationType.ID = "AllocationTypeProvider";
            this.dgAllocation.EditorProviders.Add(ddp_AllocationType);
            var ddl_allocationType = ((DropDownProvider)dgAllocation.EditorProviders["AllocationTypeProvider"]).EditorControl;

            ddl_allocationType.DataSource = allocations.Tables[1];
            ddl_allocationType.TextField = "ST_NAME";
            ddl_allocationType.ValueField = "ST_ID";
            ddl_allocationType.DataBind();
            ddl_allocationType.Items.Insert(0, new DropDownItem("--None--", "0"));

            DropDownProvider ddp_fromTypeProvider = new DropDownProvider();
            ddp_fromTypeProvider.ID = "FromTypeProvider";
            this.dgAllocation.EditorProviders.Add(ddp_fromTypeProvider);
            var ddl_fromTypeProvider = ((DropDownProvider)dgAllocation.EditorProviders["FromTypeProvider"]).EditorControl;
            ddl_fromTypeProvider.Items.Insert(0, new DropDownItem("--None--", "0"));
            ddl_fromTypeProvider.Items.Add(new DropDownItem("CLIENT", "CLIENT"));
            ddl_fromTypeProvider.Items.Add(new DropDownItem("STUDY", "STUDY"));
            ddl_fromTypeProvider.DataBind();

            DropDownProvider ddp_fromCCProvider = new DropDownProvider();
            ddp_fromCCProvider.ID = "FromCCProvider";
            var ddl_fromccProvider = ((DropDownProvider)dgAllocation.EditorProviders["FromCCProvider"]).EditorControl;
            this.dgAllocation.EditorProviders.Add(ddp_fromCCProvider);
            ddl_fromccProvider.DataSource = allocations.Tables[2]; ;
            ddl_fromccProvider.TextField = "CC_NAME";
            ddl_fromccProvider.ValueField = "CC_ID";
            ddl_fromccProvider.DataBind();
            ddl_fromccProvider.Items.Insert(0, new DropDownItem("--None--", "0"));

        }

        #endregion



        protected void btnCopyForward_Click(object sender, EventArgs e)
        {
            AllocationsService svc = new AllocationsService();
            try
            {

                svc.copyForwardAllocations(currentMI.modelInstanceID);
                bindAllocationData();
            }
            catch (Exception exp)
            {
                logutils.createExceptionLogEntry(exp, svc.authenticationInfo.userId);
                //                msgs.Add(CONST_ERR_MSG_GENERIC);

            }
        }

        protected void dgAllocation_RowAdding(object sender, RowAddingEventArgs e)
        {

        }

        protected void dgAllocation_RowAdded(object sender, RowAddedEventArgs e)
        {

        }

        //protected void dgAllocation_InitializeRow(object sender, Infragistics.Web.UI.GridControls.RowEventArgs e)
        //{
        //    if (((System.Data.DataRowView)(e.Row.DataItem)).Row["Notes"] == DBNull.Value)
        //    {
        //        e.Row.Items.FindItemByKey("Notes").Text = "....";
        //    }
        //}



    }
}
